# Generated by Django 5.1.1 on 2024-09-24 17:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('channels', '0009_messagge_provider'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messagge',
            name='messages',
            field=models.CharField(max_length=300),
        ),
    ]
