# Generated by Django 5.1.1 on 2024-09-20 17:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0009_customergroup_partner'),
        ('channels', '0006_customerchannel_order'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='customerchannel',
            unique_together={('order', 'customer')},
        ),
    ]
