error_codes_labs = [
    {
        "0": "Message has been successfully sent",
        "10": "Missing XML data in request",
        "11": "Badly formed XML in request",
        "20": "The message element must be present in the request",
        "21": "The message element cannot be empty",
        "23": "There are no recipients",
        "24": "Too many recipients",
        "27": "This message contained one or more invalid character(s)",
        "28": "Subid is exceeding maximum length",
        "30": "There was an error while sending the message",
        "35": "The account has no enough credit for this sending",
        "39": "The value of the scheduled field is not a valid datetime format",
        "41": "Scheduled messages cannot be sent in test mode",
        "51": "Compulsary fields not defined",
        "52": "Scheduled messages not found"
    }
]
