# Generated by Django 5.1.1 on 2024-09-24 16:12

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('channels', '0008_alter_customerchannel_unique_together'),
    ]

    operations = [
        migrations.AddField(
            model_name='messagge',
            name='provider',
            field=models.ForeignKey(default='', on_delete=django.db.models.deletion.CASCADE, to='channels.provider'),
            preserve_default=False,
        ),
    ]
